# Contributing

When contributing to this repository, please first discuss the change you wish
to make via issue, email, or any other method to the owners or maintainers of
this repository before making a change. It is recommended to create a separate
branch and propose a change via merge request.

Here are some ways you can contribute:

* by using alpha, beta, and pre-release versions
* by reporting bugs and issues
* by suggesting new features
* by refactoring code
* by writing or editing documentation
* by writing code (fix typos, add comments, fix code style)
* by closing issues
* by reviewing patches
* by testing the API

No contribution is too small, any kind of contribution will be highly
appreciated.
